# coding: utf-8

"""
    Mentortools Access Server

    Mentortools service for Access Packages with lazy access resolution

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from access_server_connector_v2.models.wrapped_response_resolve_out import WrappedResponseResolveOut

class TestWrappedResponseResolveOut(unittest.TestCase):
    """WrappedResponseResolveOut unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WrappedResponseResolveOut:
        """Test WrappedResponseResolveOut
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WrappedResponseResolveOut`
        """
        model = WrappedResponseResolveOut()
        if include_optional:
            return WrappedResponseResolveOut(
                done = True,
                result = access_server_connector_v2.models.resolve_out.ResolveOut(
                    root = access_server_connector_v2.models.node_access_out.NodeAccessOut(
                        resource_type = 'course', 
                        resource_id = 56, 
                        state = 'available', 
                        allowed = True, 
                        available_at = 56, 
                        expires_at = 56, 
                        lock_reason = null, 
                        winning_layer = null, 
                        reasons = [
                            56
                            ], 
                        expired_message = '', 
                        children = [
                            access_server_connector_v2.models.node_access_out.NodeAccessOut(
                                resource_type = 'course', 
                                resource_id = 56, 
                                state = 'available', 
                                allowed = True, 
                                available_at = 56, 
                                expires_at = 56, 
                                lock_reason = null, 
                                winning_layer = null, 
                                reasons = [
                                    56
                                    ], 
                                expired_message = '', 
                                children = [
                                    
                                    ], )
                            ], ), 
                    next_transition = 56, )
            )
        else:
            return WrappedResponseResolveOut(
                result = access_server_connector_v2.models.resolve_out.ResolveOut(
                    root = access_server_connector_v2.models.node_access_out.NodeAccessOut(
                        resource_type = 'course', 
                        resource_id = 56, 
                        state = 'available', 
                        allowed = True, 
                        available_at = 56, 
                        expires_at = 56, 
                        lock_reason = null, 
                        winning_layer = null, 
                        reasons = [
                            56
                            ], 
                        expired_message = '', 
                        children = [
                            access_server_connector_v2.models.node_access_out.NodeAccessOut(
                                resource_type = 'course', 
                                resource_id = 56, 
                                state = 'available', 
                                allowed = True, 
                                available_at = 56, 
                                expires_at = 56, 
                                lock_reason = null, 
                                winning_layer = null, 
                                reasons = [
                                    56
                                    ], 
                                expired_message = '', 
                                children = [
                                    
                                    ], )
                            ], ), 
                    next_transition = 56, ),
        )
        """

    def testWrappedResponseResolveOut(self):
        """Test WrappedResponseResolveOut"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
